@@ -1,9 +1,8 @@
-from .pq import Pipeline, _import_global, JSONItemList
-import json, sys, os
+from .pq import Pipeline, _import_global
+import sys, os
 import argparse
 
 
-
 def main():
     parser = argparse.ArgumentParser(
         description="pq is a Python command-line JSON processor"
@@ -24,8 +23,6 @@ def main():
     if args.imports:
         _import_global(args.imports)
 
-
-
     pipeline = Pipeline(json_stream=sys.stdin, str_input=args.expression)
 
     pipeline.run()
